==> rc-ui-lib-0.1.58.tgz: package/es/flex/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import * as React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import Flex from '..';
describe('Flex', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render correctly', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, null, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 12
            }, "span: 12"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 12
            }, "span: 12")));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render correctly when using gutter prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              gutter: 16
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8")));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should render correctly when gutter prop is array', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              gutter: [16, -16]
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8")));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render correctly when direction prop is row-reverse', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              direction: "row-reverse"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-3")));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render correctly when wrap prop is wrap', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              wrap: "wrap"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-3")));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render correctly when using justify prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              justify: "between"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-3")));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render correctly when using align prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              align: "center"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-3")));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render correctly when using flex prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              align: "center"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              flex: 2
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              flex: 5
            }, "span: 8-2")));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render correctly when flex prop is decimal', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              align: "center"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              flex: "20px"
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              flex: 5
            }, "span: 8-2")));
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
});

==> rc-ui-lib-0.2.4.tgz: package/es/flex/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import * as React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import Flex from '..';
describe('Flex', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render correctly', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, null, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 12
            }, "span: 12"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 12
            }, "span: 12")));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render correctly when using gutter prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              gutter: 16
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8")));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should render correctly when gutter prop is array', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              gutter: [16, -16]
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8")));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render correctly when direction prop is row-reverse', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              direction: "row-reverse"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-3")));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render correctly when wrap prop is wrap', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              wrap: "wrap"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-3")));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render correctly when using justify prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              justify: "between"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-3")));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render correctly when using align prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              align: "center"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React.createElement(Flex.Item, {
              span: 8
            }, "span: 8-3")));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render correctly when using flex prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              align: "center"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              flex: 2
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              flex: 5
            }, "span: 8-2")));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render correctly when flex prop is decimal', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Flex, {
              align: "center"
            }, /*#__PURE__*/React.createElement(Flex.Item, {
              flex: "20px"
            }, "span: 8-1"), /*#__PURE__*/React.createElement(Flex.Item, {
              flex: 5
            }, "span: 8-2")));
            expect(toJson(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
});
